@@ -104,9 +104,9 @@ pub fn process_cast_vote(
         }
     };
 
-    let governing_token_supply = get_spl_token_mint_supply(governing_token_mint_info)?;
+    let governing_token_mint_supply = get_spl_token_mint_supply(governing_token_mint_info)?;
     proposal_data.try_tip_vote(
-        governing_token_supply,
+        governing_token_mint_supply,
         &governance_data.config,
         clock.unix_timestamp,
     );
