@@ -93,6 +93,11 @@ pub struct Proposal {
     /// after vote was completed.
     pub governing_token_mint_vote_supply: Option<u64>,
 
+    /// The vote threshold percentage at the time Proposal was decided
+    /// It's used to show correct vote results for historical proposals in cases when the threshold
+    /// was changed for governance config after vote was completed.
+    pub vote_threshold_percentage: Option<VoteThresholdPercentage>,
+
     /// Proposal name
     pub name: String,
 
@@ -102,7 +107,7 @@ pub struct Proposal {
 
 impl AccountMaxSize for Proposal {
     fn get_max_size(&self) -> Option<usize> {
-        Some(self.name.len() + self.description_link.len() + 202)
+        Some(self.name.len() + self.description_link.len() + 205)
     }
 }
 
@@ -209,7 +214,10 @@ impl Proposal {
 
         self.state = self.get_final_vote_state(governing_token_mint_supply, config);
         self.voting_completed_at = Some(current_unix_timestamp);
+
+        // Capture vote params to correctly display historical results
         self.governing_token_mint_vote_supply = Some(governing_token_mint_supply);
+        self.vote_threshold_percentage = Some(config.vote_threshold_percentage.clone());
 
         Ok(())
     }
@@ -248,7 +256,10 @@ impl Proposal {
         {
             self.state = tipped_state;
             self.voting_completed_at = Some(current_unix_timestamp);
+
+            // Capture vote params to correctly display historical results
             self.governing_token_mint_vote_supply = Some(governing_token_mint_supply);
+            self.vote_threshold_percentage = Some(config.vote_threshold_percentage.clone());
         }
     }
 
@@ -489,6 +500,7 @@ mod test {
             instructions_executed_count: 10,
             instructions_count: 10,
             instructions_next_index: 10,
+            vote_threshold_percentage: Some(VoteThresholdPercentage::YesVote(100)),
         }
     }
 
