@@ -66,6 +66,15 @@ async fn test_cast_vote() {
     );
 
     assert_eq!(Some(100), proposal_account.governing_token_mint_vote_supply);
+    assert_eq!(
+        Some(
+            account_governance_cookie
+                .account
+                .config
+                .vote_threshold_percentage
+        ),
+        proposal_account.vote_threshold_percentage
+    );
 
     let token_owner_record = governance_test
         .get_token_owner_record_account(&token_owner_record_cookie.address)
