@@ -62,7 +62,7 @@ use self::{
     cookies::{
         GovernanceCookie, GovernedAccountCookie, GovernedMintCookie, GovernedProgramCookie,
         GovernedTokenCookie, ProposalCookie, ProposalInstructionCookie, RealmCookie,
-        TokeOwnerRecordCookie, VoteRecordCookie,
+        TokeOwnerRecordCookie, TokenAccountCookie, VoteRecordCookie,
     },
     tools::NopOverride,
 };
@@ -1133,6 +1133,7 @@ impl GovernanceProgramTest {
 
             execution_flags: InstructionExecutionFlags::None,
             governing_token_mint_vote_supply: None,
+            vote_threshold_percentage: None,
         };
 
         let proposal_address = get_proposal_address(
@@ -1906,6 +1907,32 @@ impl GovernanceProgramTest {
         .unwrap();
     }
 
+    #[allow(dead_code)]
+    pub async fn with_token_account(
+        &mut self,
+        token_mint: &Pubkey,
+        owner: &Pubkey,
+        token_mint_authority: &Keypair,
+        amount: u64,
+    ) -> TokenAccountCookie {
+        let token_account_keypair = Keypair::new();
+
+        self.create_empty_token_account(&token_account_keypair, token_mint, owner)
+            .await;
+
+        self.mint_tokens(
+            token_mint,
+            token_mint_authority,
+            &token_account_keypair.pubkey(),
+            amount,
+        )
+        .await;
+
+        return TokenAccountCookie {
+            address: token_account_keypair.pubkey(),
+        };
+    }
+
     #[allow(dead_code)]
     pub async fn create_token_account_with_transfer_authority(
         &mut self,
